part of 'add_photo_cubit.dart';

@immutable
abstract class AddPhotoState {}

class AddPhotoInitial extends AddPhotoState {}

class AddPhotoLoading extends AddPhotoState {}

class AddPhotoLoaded extends AddPhotoState {
  final List<String> imageUrls;
  final int remainingPhotos;

  AddPhotoLoaded(this.imageUrls, this.remainingPhotos);
}

class AddPhotoError extends AddPhotoState {
  final String message;

  AddPhotoError(this.message);
}